@@ -46,11 +46,10 @@ spurious <- function(x) {
   bslib::accordion(x)
   DT::renderDataTable(x)
   dplyr::add_count(x)
-  future::as.cluster(x)
   httr2::curl_help(x)
   leaflet.extras::removeDrawToolbar(x)
+  mirai::mirai(x)
   markdown::html_format(x)
-  promises::as.promise(x)
   R6::R6Class(x)
   RColorBrewer::brewer.pal(x)
   rintrojs::introjs(x)
