@@ -146,9 +146,8 @@ function(input, output, session) {
   ### RUN MODULE ON ENTER ####
   ############################################# #
 
-  observeEvent(input$run_module, {
-    req(module())
-    shinyjs::runjs(glue::glue("document.getElementById('{module()}-run').click();"))
+  observe({
+    shinyjs::js$runOnEnter(module())
   })
 
   ####################
